==> gfal2_2.0.0.orig.tar.gz: gfal2-2.0.0/src/common/srm/gfal_srm_request.c <==
/*
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */



#include "gfal_srm_request.h"

gfal_srm_params_t gfal_srm_params_new(gfal_srm_plugin_t handle, GError ** err ){
	gfal_srm_params_t res = g_new0(struct _gfal_srm_params,1);
	res->protocols = handle->opt_srmv2_protocols;
	res->desiredpintime= handle->opt_srmv2_desiredpintime;
	res->proto_version = handle->srm_proto_type;
    res->spacetokendesc= g_strdup(handle->opt_srmv2_spacetokendesc);
	return res;
}

 void gfal_srm_params_free(gfal_srm_params_t params){
     if(params){
         g_free(params->spacetokendesc);
         g_free(params);
     }
 }
 
 
char ** gfal_srm_params_get_protocols(gfal_srm_params_t params){
		return params->protocols;
}

gchar* gfal_srm_params_get_spacetoken(gfal_srm_params_t params){
    return params->spacetokendesc;
}

void gfal_srm_params_set_spacetoken(gfal_srm_params_t params, const char* spacetoken){
    g_free(params->spacetokendesc);
    params->spacetokendesc = g_strdup(spacetoken);
}

void gfal_srm_params_set_protocols(gfal_srm_params_t params, char** protocols){
	params->protocols = protocols;
}

==> gfal2_2.3.0.orig.tar.gz: gfal2-2.3.0/src/common/srm/gfal_srm_request.c <==
/*
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */



#include "gfal_srm_request.h"

gfal_srm_params_t gfal_srm_params_new(gfal_srm_plugin_t handle, GError ** err ){
	gfal_srm_params_t res = g_new0(struct _gfal_srm_params,1);
    res->protocols = srm_get_turls_sup_protocol(handle->handle);
	res->desiredpintime= handle->opt_srmv2_desiredpintime;
	res->proto_version = handle->srm_proto_type;
    res->spacetokendesc= g_strdup(handle->opt_srmv2_spacetokendesc);
    res->file_size = 0;
	return res;
}

 void gfal_srm_params_free(gfal_srm_params_t params){
     if(params){
         g_free(params->spacetokendesc);
         g_strfreev(params->protocols);
         g_free(params);
     }
 }
 
 
char ** gfal_srm_params_get_protocols(gfal_srm_params_t params){
		return params->protocols;
}

gchar* gfal_srm_params_get_spacetoken(gfal_srm_params_t params){
    return params->spacetokendesc;
}

void gfal_srm_params_set_spacetoken(gfal_srm_params_t params, const char* spacetoken){
    g_free(params->spacetokendesc);
    params->spacetokendesc = g_strdup(spacetoken);
}


void gfal_srm_params_set_protocols(gfal_srm_params_t params, char** protocols){
    if(params->protocols)
        g_strfreev(params->protocols);
	params->protocols = protocols;
}

void gfal_srm_params_set_size(gfal_srm_params_t params, size_t file_size){
    params->file_size = file_size;
}
